@@ -31,9 +31,9 @@ class Email:
         subject -- str: Email subject
         message -- str: Email content/message
         """
-        email = f'Name: {self.name}\nEmail: {self.email}\nSubject: {self.subject}\nMessage: {message}'
+#         email = f'Name: {self.name}\nEmail: {self.email}\nSubject: {self.subject}\nMessage: {message}'
         msg = EmailMessage()
-        msg.set_content(email)
+        msg.set_content(message)
         msg['Subject'] = subject
         msg['From'] = self.sender
         msg['To'] = self.recipient
